thorn.reverse — Thorn 1.3.0 documentation

# thorn.reverse

- thorn.webhook.reverse

## thorn.webhook.reverse

Tools for URL references.

class `thorn.reverse.` `model_reverser`(view_name, *args, **kwargs)

  Describes how to get the canonical URL for a model instance.

  Examples

      >>> model_reverser('article-detail', uuid='uuid')
      # for an article instance will generate the URL by calling:
      >>> reverse('article_detail', kwargs={'uuid': instance.uuid})

      >>> model_reverser('article-detail', 'category.name', uuid='uuid')
      # for an article instance will generate the URL by calling:
      >>> reverse('article-detail',
      ...         args=[instance.category.name],
      ...         kwargs={'uuid': instance.uuid},
      ... )